/*jslint newcap: true, plusplus: true, nomen: true */
/*globals OS_IOS, _ */

/**
 * @formatter:off
 * 
 * Creates a list of events
 * 
 * @param {Object} [args]
 * 
 * @formatter:on
 */
(function (args) {
    "use strict";

    var moment = require("alloy/moment"),
        currentEvents;

    function getSection(name, dayDate, today) {
        
        var dayEvents = [];
        
        _.each(currentEvents, function (event) {
            
            var eventDate;
            
            if (event.startDate) {
                eventDate = moment.utc(event.startDate);
            } else if (event.endDate) {
                eventDate = moment.utc(event.endDate);
            }
            
            if (eventDate && eventDate.isSame(dayDate, "day")) {
                dayEvents.push(event);
            } else if (today && eventDate < dayDate && event.endDate) {
                eventDate = moment.utc(event.endDate);
                // A multi-day event that started before today and ends today or later.
                if (eventDate && (eventDate.isSame(dayDate, "day") || eventDate.isAfter(dayDate))) {
                    dayEvents.push(event);
                }
            }
            
        });
        
        if (dayEvents.length > 0) {
            
            return Alloy.createController("eventlistsection", {
                name: name,
                events: dayEvents
            }).getView();
            
        }

    }

    function loadEventList() {
        
        // We need to do some date manipulation here.
        // Get now so that we know the date that the user sees on the device.
        // Create a moment in UTC with that date without any time info so we
        // don't need to worry about time zones.
        // Add days to today (need to clone or today is updated) to get the next few days.
        //
        // This is not easily testable since it requires the device time to be changed.
        var now = moment(),
            today = moment.utc([now.year(), now.month(), now.date()]),
            tomorrow = today.clone().add(1, "days"),
            twoDays = today.clone().add(2, "days"),
            threeDays = today.clone().add(3, "days"),
            todaySect = getSection("Today", today, true),
            tomorrowSect = getSection("Tomorrow", tomorrow),
            twoDaysSect = getSection("2 days", twoDays),
            threeDaysSect = getSection("3 days", threeDays);
        
        if (todaySect) {
            $.eventListView.appendSection(todaySect);
        }
        
        if (tomorrowSect) {
            $.eventListView.appendSection(tomorrowSect);
        }
        
        if (twoDaysSect) {
            $.eventListView.appendSection(twoDaysSect);
        }
        
        if (threeDaysSect) {
            $.eventListView.appendSection(threeDaysSect);
        }
        
    }

    function init() {
        currentEvents = [
            {
                "name": "Today",
                "startDate": moment.utc().format("YYYY-MM-DDT00:00:00.000") + "Z",
                "eventId": {
                    "value": "c1cae110-4a80-41dd-a876-4713d84e94d9"
                }
            },
            {
                "name": "Later Today",
                "startDate": moment.utc().format("YYYY-MM-DDT00:00:00.000") + "Z",
                "startTime": "2015-01-01T17:05:00.000Z",
                "eventId": {
                    "value": "c1cae110-4a80-41dd-a876-4713d84e94d9"
                }
            },
            {
                "name": "Tomorrow",
                "startDate": moment.utc().add('day', 1).format("YYYY-MM-DDT00:00:00.000") + "Z",
                "eventId": {
                    "value": "c1cae110-4a80-41dd-a876-4713d84e94d9"
                }
            },
            {
                "name": "WWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWWW",
                "startDate": moment.utc().format("YYYY-MM-DDT00:00:00.000") + "Z",
                "eventId": {
                    "value": "c1cae110-4a80-41dd-a876-4713d84e94d9"
                }
            }
        ];
        loadEventList();
        
        $.win.open();
    }
    
    exports.GoBack = function () {
        $.win.close();
    };
    
    init();
    
}(arguments[0] || {}));

function goBack() {
    exports.GoBack.call();
}
